.. python-unrar documentation master file, created by
   sphinx-quickstart on Sun Aug 26 20:22:26 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

python-unrar
========================================

`python-unrar <http://github.com/matiasb/python-unrar>`_ provides a high-level
module for reading and listing RAR archives inspired on Python's
`zipfile <http://docs.python.org/library/zipfile.html>`_.


:mod:`rarfile` is built on top of :mod:`unrarlib`, a low-level ctypes wrapper
for the `UnRAR library <http://www.rarlab.com/rar_add.htm>`_.

Contents:

.. toctree::
   :maxdepth: 2

   rarfile
   unrarlib
   constants


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

